import Vue from "vue";
import Router from "vue-router";
import { ZdPage } from "@zeedhi/vue";
import Store from '../store';

Vue.use(Router);

const router = new Router({
	mode: "history",
	base: process.env.BASE_URL,
	routes: [
		{
			path: "/",
			name: "home",
			component: () => import("../pages/Home.vue")
		},
		{
			path: "/clientes-por-operador",
			name: "clientsByOperator",
			component: () => import("../pages/ClientesPorOperador/Index.vue")
		},
		{
			path: "/operadores-por-cliente",
			name: "operatorsByClient",
			component: () => import("../pages/OperadoresPorCliente/Index.vue")
		},
		{
			path: "*",
			component: ZdPage,
			props: {
				path: "notfound",
				local: true
			}
		}
	]
});

router.beforeEach((to, from, next) => {
    if (window.parent !== window && to.name !== 'token-error') { // if application is called inside a iframe
        if (to.query.token) {
			// if token was passed
			localStorage.setItem('APP_LOGIN_TOKEN', JSON.stringify(to.query.token));
			if (to.query.hash !== '0') {
				localStorage.setItem('APP_LOGIN_HASH', JSON.stringify(to.query.hash));
			}
            Store.commit('setAppLoginToken', to.query.token);
            Store.commit('setAppDisplayOptions', { menu: to.query.menu, header: to.query.header });
        }

        if (!Store.state.appLoginToken) {
            // if there is no token... redirect to another page
            Store.commit('setAppDisplayOptions', { menu: '0', header: '0' });
            next('/token-error');
            return;
        }

        // remove parameters from requested page
        delete to.query.menu;
        delete to.query.header;
        delete to.query.token;
    }

    next();
});

export default router;
